@@ -1,4 +1,4 @@
-# $Id: Manifest.pm,v 1.16 2006/08/29 22:38:48 comdog Exp $
+# $Id: Manifest.pm 2478 2008-01-06 20:06:49Z comdog $
 package Test::Manifest;
 use strict;
 
@@ -6,16 +6,12 @@ use base qw(Exporter);
 use vars qw(@EXPORT_OK @EXPORT $VERSION);
 
 use Carp qw(carp);
-use Exporter;
 use File::Spec::Functions qw(catfile);
 
-require Test::More;
-*diag = *Test::More::diag;
-
 @EXPORT    = qw(run_t_manifest);
 @EXPORT_OK = qw(get_t_files make_test_manifest manifest_name);
 
-$VERSION = sprintf "%d.%02d_01", q$Revision: 1.16 $ =~ m/ (\d+) \. (\d+) /x;
+$VERSION = '1.22_01';
 
 my $Manifest = catfile( "t", "test_manifest" );
 my %SeenInclude = ();
@@ -23,7 +19,7 @@ my %SeenTest = ();
 
 require 5.006;
 
-*MY::test_via_harness = sub
+sub MY::test_via_harness
 	{
 	my($self, $perl, $tests) = @_;
 
@@ -95,10 +91,12 @@ sub run_t_manifest
 
 	my( $level ) = $_[2] || ();
 	
-	print STDERR "Level is $level\n";
+	print STDERR "Level is $level\n" 
+		if $Test::Harness::verbose;
 	
 	my @files = get_t_files( $level );
-	print STDERR "Test::Manifest::test_harness found [@files]\n";
+	print STDERR "Test::Manifest::test_harness found [@files]\n" 
+		if $Test::Harness::verbose;
 
 	Test::Harness::runtests( @files );
 	}
@@ -136,7 +134,17 @@ current working directory, unlike the filenames, which are relative
 to C<t/>. The filenames in the included are still relative to C<t/>.
 
 	;include t/file_with_other_test_names.txt
-	
+
+Also experimentally, you can stop Test::Manifest from reading filenames
+with the C<;skip> directive. Test::Harness will skip the filenames up to
+the C<;unskip> directive (or end of file)
+
+	run_this1
+	;skip
+	skip_this
+	;unskip
+	run_this2
+
 To select sets of tests, specify the level in the variable TEST_LEVEL
 during `make test`. 
 
@@ -148,7 +156,8 @@ during `make test`.
 sub get_t_files
 	{
 	my $upper_bound = shift;
-	diag( "Test level is $upper_bound\n" ) if $Test::Harness::verbose;
+	print STDERR "# Test level is $upper_bound\n"
+		if $Test::Harness::verbose;
 	
 	%SeenInclude = ();
 	%SeenTest    = ();
@@ -170,20 +179,32 @@ sub _load_test_manifest
 	my $upper_bound = shift || 0;
 	my @tests = ();
 
-	while( <$fh> )
+	LINE: while( <$fh> )
 		{
 		s/#.*//; s/^\s+//; s/\s+$//;
 
 		next unless $_;
 
 		my( $command, $arg ) = split/\s+/, $_, 2;
-		if( $command eq ';include' ) 
+		if( ';' eq substr( $command, 0, 1 ) )
 			{
-			my $result = _include_file( $arg, $., $upper_bound );
-			push @tests, @$result if defined $result;
-			next;
+			if( $command eq ';include' ) 
+				{
+				my $result = _include_file( $arg, $., $upper_bound );
+				push @tests, @$result if defined $result;
+				next;
+				}
+			elsif( $command eq ';skip' ) 
+				{
+				while( <$fh> ) { last if m/^;unskip/ }
+				next LINE;
+				}
+			else
+				{
+				croak( "Unknown directive: $command" );
+				}
 			}
-
+			
 		my( $test, $level ) = ( $command, $arg );
 		$level = 1 unless defined $level;
 		
@@ -209,7 +230,8 @@ sub _load_test_manifest
 sub _include_file
 	{
 	my( $file, $line, $upper_bound ) = @_;
-	diag( "Including file $file at line $line\n" ) if $Test::Harness::verbose;
+	print STDERR "# Including file $file at line $line\n" 
+		if $Test::Harness::verbose;
 	
 	unless( -e $file )
 		{
@@ -292,13 +314,14 @@ feature.
 
 brian d foy, C<< <bdfoy@cpan.org> >>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2006, brian d foy, All Rights Reserved
+Copyright (c) 2002-2008 brian d foy.  All rights reserved.
 
-You may use and distribute this module under the same terms
-as Perl itself
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
+
 1;
